# Translate

Translate all atoms in your system by a given vector using [`MDAnalysis.transformations.translate.translate`](https://docs.mdanalysis.org/stable/documentation_pages/transformations/translate.html#MDAnalysis.transformations.translate.translate).

<video controls>
  <source src="../../movies/mda-tui-translate.mp4" type="video/mp4">
</video>
